import babel from 'gulp-babel';
import gulp from 'gulp';
import flatten from 'gulp-flatten';
import plumber from 'gulp-plumber';
import rename from 'gulp-rename';
import uglify from 'gulp-uglify';
import postcss from 'gulp-postcss';
import cssnano from 'cssnano';
import cssnext from 'postcss-cssnext';
import mediaMove from 'postcss-move-media';
import postcssImport from 'postcss-import';
import sourcemaps from 'gulp-sourcemaps';


const processors = [
    postcssImport(),
    mediaMove(),
    cssnext({
        browsers: ['last 10 version'],
        warnForDuplicates: false
    }),
    cssnano(),
];

gulp.task('js', () => (
    gulp.src('./src/**/*.js')
        .pipe(plumber())
        .pipe(babel({
            presets: ['es2015', 'stage-0']
        }))
        .pipe(uglify())
        .pipe(flatten({ includeParents: 0 }))
        .pipe(gulp.dest('./dist'))
));

gulp.task('css', () => (
    gulp.src('./src/**/*.css')
        .pipe(plumber())
        .pipe(flatten({ includeParents: 0 }))
        .pipe(gulp.dest('./dist'))
));

gulp.task('demo-css', () => (
    gulp.src('./demo/css/demo.css')
        .pipe(plumber())
        .pipe(sourcemaps.init())
        .pipe(postcss(processors))
        .pipe(rename({
            suffix: '.min'
        }))
        .pipe(sourcemaps.write('./'))
        .pipe(gulp.dest('./demo/css/'))
));

gulp.task('watch-demo-css', () => {
    gulp.watch([
        './demo/css/demo.css',
        './src/**/*.css'
    ], gulp.series('demo-css'))
});