const webpack = require('webpack');
const path = require('path');

function isExternal(module) {
    const userRequest = module.userRequest;

    if (typeof userRequest !== 'string') {
        return false;
    }

    return userRequest.indexOf('bower_components') >= 0 ||
        userRequest.indexOf('node_modules') >= 0 ||
        userRequest.indexOf('vendor') >= 0;
}

module.exports = {
    entry: {
        demo: './demo/js/demo',
    },
    output: {
        path: './demo/js/',
        filename: '[name].min.js',
    },
    // devtool: 'eval-cheap-module-source-map',
    module: {
        loaders: [
            {
                loaders: ['babel-loader'],
                test: /\.js$/,
                include: [
                    path.resolve(__dirname, 'demo/'),
                    path.resolve(__dirname, 'src/'),
                    // path.resolve(__dirname, 'node_modules'),
                ],
                plugins: ['transform-runtime'],
                exclude: [
                    path.resolve(__dirname, 'node_modules'),
                ],
            },
        ],
    },
    resolve: {
        root: [
            path.resolve(__dirname, 'node_modules'),
        ],
    },
    plugins: [
        new webpack.optimize.UglifyJsPlugin({
            sourceMap: false,
            mangle: true,
        }),
        new webpack.optimize.CommonsChunkPlugin({
            name: 'vendor',
            minChunks: function (module) {
                return isExternal(module);
            },
        }),
    ],
    externals: {
        jquery: 'jQuery',
    },
};